==> qtjambi-nfc-5.15.5-sources.jar: io/qt/nfc/QNdefNfcUriRecord.java <==
package io.qt.nfc;


/**
 * <p>NFC RTD-URI</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html">QNdefNfcUriRecord</a></p>
 */
public class QNdefNfcUriRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#QNdefNfcUriRecord">QNdefNfcUriRecord::QNdefNfcUriRecord()</a></p>
     */
    public QNdefNfcUriRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#QNdefNfcUriRecord-1">QNdefNfcUriRecord::QNdefNfcUriRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcUriRecord(io.qt.nfc.QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#setUri">QNdefNfcUriRecord::setUri(QUrl)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setUri(io.qt.core.QUrl uri){
        setUri_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(uri));
    }
    
    @io.qt.QtUninvokable
    private native void setUri_native_cref_QUrl(long __this__nativeId, long uri);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#uri">QNdefNfcUriRecord::uri()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl uri(){
        return uri_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl uri_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNdefNfcUriRecord(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QNdefNfcUriRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNdefNfcUriRecord clone_native(long __this_nativeId);
}

==> qtjambi-nfc-5.15.13-sources.jar: io/qt/nfc/QNdefNfcUriRecord.java <==
package io.qt.nfc;


/**
 * <p>NFC RTD-URI</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html">QNdefNfcUriRecord</a></p>
 */
public class QNdefNfcUriRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#QNdefNfcUriRecord">QNdefNfcUriRecord::QNdefNfcUriRecord()</a></p>
     */
    public QNdefNfcUriRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#QNdefNfcUriRecord-1">QNdefNfcUriRecord::QNdefNfcUriRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcUriRecord(io.qt.nfc.QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#setUri">QNdefNfcUriRecord::setUri(QUrl)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setUri(io.qt.core.QUrl uri){
        setUri_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(uri));
    }
    
    @io.qt.QtUninvokable
    private native void setUri_native_cref_QUrl(long __this__nativeId, long uri);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#uri">QNdefNfcUriRecord::uri()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl uri(){
        return uri_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl uri_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNdefNfcUriRecord(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QNdefNfcUriRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNdefNfcUriRecord clone_native(long __this_nativeId);
}
